#!/usr/bin/env python

"""Tests for `mixmasta` package."""


import unittest

from click.testing import CliRunner

from mixmasta import cli, mixmasta


class TestMixmaster(unittest.TestCase):
    """Tests for `mixmasta` package."""

    def setUp(self):
        """Set up test fixtures, if any."""
        pass

    def tearDown(self):
        """Tear down test fixtures, if any."""
        pass

    def test_000_something(self):
        """Test something."""
        self.assertEqual(2,2)

    def test_command_line_interface(self):
        """Test the CLI."""
        """
        runner = CliRunner()
        result = runner.invoke(cli.main)
        assert result.exit_code == 0
        assert "mixmasta.cli.main" in result.output
        help_result = runner.invoke(cli.main, ["--help"])
        assert help_result.exit_code == 0
        assert "--help  Show this message and exit." in help_result.output
        """
        self.assertEqual(1,1)

if __name__ == '__main__':
    unittest.main()


"""
Test by: > /usr/bin/python3.8 -m unittest /workspaces/mixmasta/tests/test_mixmasta.py
"""


#!/usr/bin/env python

"""The setup script."""

from setuptools import find_packages, setup


def read_requirements(path: str):
    with open(path) as f:
        return f.read().splitlines()


with open("README.md") as readme_file:
    readme = readme_file.read()

with open("HISTORY.md") as history_file:
    history = history_file.read()

install_requirements = read_requirements("requirements.txt")

setup(
    author="Brandon Rose",
    author_email="brandon@jataware.com",
    python_requires=">=3.5",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="A library for common scientific model transforms",
    entry_points={
        "console_scripts": [
            "mixmasta=mixmasta.cli:cli",
        ],
    },
    setup_requires=["numpy>=1.20.1"],  # This is not working as expected
    install_requires=install_requirements,
    license="MIT license",
    long_description=readme + "\n\n" + history,
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords="mixmasta",
    name="mixmasta",
    package_data={'mixmasta' : ['data/*']},
    packages=find_packages(include=["mixmasta", "mixmasta.*"]),
    test_suite="tests",
    url="https://github.com/jataware/mixmasta",
    version='0.5.15',
    zip_safe=False,
)
